@@ -288,6 +288,8 @@ static void do_conf(const char *rcfile)
 			delay *= 60;
 		} else if (strcmp(buffer, "metric")   == 0) {
 			metric = 1;
+		} else if (strcmp(buffer, "imperial")   == 0) {
+			metric = 0;
 		} else if (strcmp(buffer, "hPa")      == 0) {
 			hPa  = 1;
 			mmHg = 0;
@@ -363,6 +365,7 @@ static void do_opts(int argc, char *argv[])
 		{"station",    1, NULL, 's'},
 		{"delay",      1, NULL, 'd'},
 		{"metric",     0, NULL, 'm'},
+		{"imperial",   0, NULL, 'i'},
 		{"hPa",        0, NULL, 'a'},
 		{"kPa",        0, NULL, 'k'},
 		{"mmHg",       0, NULL, 'g'},
@@ -396,7 +399,7 @@ static void do_opts(int argc, char *argv[])
 			mmHg   = 1;
 		}
 	while (1) {
-		if ((i = getopt_long(argc, argv, "s:d:makgbnpwWeut:x:U:chv", long_opts, NULL)) == -1)
+		if ((i = getopt_long(argc, argv, "s:d:miakgbnpwWeut:x:U:chv", long_opts, NULL)) == -1)
 			break;
 		switch (i) {
 		case 's':
@@ -428,6 +431,9 @@ static void do_opts(int argc, char *argv[])
 		case 'm':
 			metric = 1;
 			break;
+		case 'i':
+			metric = 0;
+			break;
 		case 'a':
 			hPa  = 1;
 			mmHg = 0;
@@ -494,6 +500,7 @@ static void do_opts(int argc, char *argv[])
 			printf("  -c, --compat          use version 1 monitor style, default in wmWeather,\n");
 			printf("  -d, --delay=[@]<min>  update delay, use @ for minutes past the hour,\n");
 			printf("  -m, --metric          display metric values: °C, hPa, km/h,\n");
+			printf("  -i, --imperial        display metric values: °F, mmHg, mi/h,\n");
 			printf("  -w, --chill           display wind chill instead of dew point,\n");
 			printf("  -e, --heat            display heat index instead of dew point,\n");
 			printf("  -b, --beaufort        display windspeed in Beaufort,\n");
